@@ -465,8 +465,9 @@ class CephFSDriver(driver.ExecuteMixin, driver.GaneshaMixin,
             "sub_name": share["id"],
             "size": size,
             "namespace_isolated": True,
-            "mode": self._cephfs_volume_mode,
+            "mode": self._cephfs_volume_mode
         }
+
         if share['share_group_id'] is not None:
             argdict.update({"group_name": share["share_group_id"]})
 
@@ -540,8 +541,14 @@ class CephFSDriver(driver.ExecuteMixin, driver.GaneshaMixin,
             share_server=share_server)
 
     def ensure_share(self, context, share, share_server=None):
-        # Creation is idempotent
-        return self.create_share(context, share, share_server)
+        try:
+            export_location = self._get_export_locations(share)
+        except exception.ShareBackendException as e:
+            if 'does not exist' in str(e).lower():
+                raise exception.ShareResourceNotFound(share_id=share['id'])
+            raise
+
+        return export_location
 
     def extend_share(self, share, new_size, share_server=None):
         # resize FS subvolume/share
@@ -1033,7 +1040,7 @@ class NFSProtocolHelperMixin():
                             "a hostname (rather than IP address) was supplied "
                             "in 'cephfs_ganesha_server_ip' or "
                             "in 'cephfs_ganesha_export_ips'.")
-                return [4, 6]
+                self.configured_ip_versions = {4, 6}
         return list(self.configured_ip_versions)
 
 
@@ -1112,7 +1119,8 @@ class NFSProtocolHelper(NFSProtocolHelperMixin, ganesha.GaneshaNASHelper2):
         return {
             'Name': 'Ceph',
             'User_Id': ceph_auth_id,
-            'Secret_Access_Key': auth_result
+            'Secret_Access_Key': auth_result,
+            'Filesystem': self.volname
         }
 
     def _cleanup_fsal_hook(self, base, share, access):
@@ -1177,7 +1185,7 @@ class NFSClusterProtocolHelper(NFSProtocolHelperMixin, ganesha.NASHelperBase):
         export_ips = []
 
         argdict = {
-            "nfs_cluster_id": nfs_clusterid,
+            "cluster_id": nfs_clusterid,
         }
 
         output = rados_command(self.rados_client, "nfs cluster info", argdict)
@@ -1196,6 +1204,13 @@ class NFSClusterProtocolHelper(NFSProtocolHelperMixin, ganesha.NASHelperBase):
         else:
             export_ips.append(vip)
 
+        # there are no export IPs, there are no NFS servers we can use
+        if not export_ips:
+            msg = _("There are no NFS servers available to use. "
+                    "Please check the health of your Ceph cluster "
+                    "and restart the manila share service.")
+            raise exception.ShareBackendException(msg=msg)
+
         return export_ips
 
     def check_for_setup_error(self):
@@ -1206,7 +1221,7 @@ class NFSClusterProtocolHelper(NFSProtocolHelperMixin, ganesha.NASHelperBase):
         """Allow access to the share."""
         export = {
             "path": self._get_export_path(share),
-            "nfs_cluster_id": self.nfs_clusterid,
+            "cluster_id": self.nfs_clusterid,
             "pseudo": self._get_export_pseudo_path(share),
             "squash": "none",
             "security_label": True,
@@ -1220,7 +1235,7 @@ class NFSClusterProtocolHelper(NFSProtocolHelperMixin, ganesha.NASHelperBase):
         }
 
         argdict = {
-            "nfs_cluster_id": self.nfs_clusterid,
+            "cluster_id": self.nfs_clusterid,
         }
 
         inbuf = json.dumps(export).encode('utf-8')
@@ -1231,7 +1246,7 @@ class NFSClusterProtocolHelper(NFSProtocolHelperMixin, ganesha.NASHelperBase):
         """Deny access to the share."""
 
         argdict = {
-            "nfs_cluster_id": self.nfs_clusterid,
+            "cluster_id": self.nfs_clusterid,
             "pseudo_path": self._get_export_pseudo_path(share)
         }
 
